@@ -37,6 +37,7 @@
 #include "controlid.h"
 
 #include <sstream>
+#include <cstring>
 
 #ifndef MAX
 #define MAX( a, b ) ( a > b ? a : b )
@@ -198,7 +199,7 @@ void ArticleViewBase::setup_action()
 {
     // アクショングループを作ってUIマネージャに登録
     action_group() = Gtk::ActionGroup::create();
-    action_group()->add( Gtk::Action::create( "BookMark", "ブックマーク設定/解除(_B)"), sigc::mem_fun( *this, &ArticleViewBase::slot_bookmark ) );
+    action_group()->add( Gtk::Action::create( "BookMark", "しおりを設定/解除(_B)"), sigc::mem_fun( *this, &ArticleViewBase::slot_bookmark ) );
     action_group()->add( Gtk::Action::create( "OpenBrowser", "ブラウザで開く(_W)"), sigc::mem_fun( *this, &ArticleViewBase::slot_open_browser ) );
     action_group()->add( Gtk::Action::create( "CopyURL", "URLをコピー(_U)"), sigc::mem_fun( *this, &ArticleViewBase::slot_copy_current_url ) );
     action_group()->add( Gtk::Action::create( "CopyNAME", "名前コピー(_N)"), sigc::mem_fun( *this, &ArticleViewBase::slot_copy_name ) );
@@ -221,9 +222,8 @@ void ArticleViewBase::setup_action()
     // 検索
     action_group()->add( Gtk::Action::create( "Search_Menu", "検索(_F)" ) );
     action_group()->add( Gtk::Action::create( "SearchWeb", CONFIG::get_menu_search_web()+"(_W)" ), sigc::mem_fun( *this, &ArticleViewBase::slot_search_web ) );
-    action_group()->add( Gtk::Action::create( "SearchCache_Menu", "キャッシュ内ログ検索(_C)" ) );
-    action_group()->add( Gtk::Action::create( "SearchCacheLocal", "この板のログのみを検索(_L)"), sigc::mem_fun( *this, &ArticleViewBase::slot_search_cachelocal ) );
-    action_group()->add( Gtk::Action::create( "SearchCacheAll", "キャッシュ内の全ログを検索(_A)") );
+    action_group()->add( Gtk::Action::create( "SearchCacheLocal", "ログ検索 (対象: 板)(_L)"), sigc::mem_fun( *this, &ArticleViewBase::slot_search_cachelocal ) );
+    action_group()->add( Gtk::Action::create( "SearchCacheAll", "ログ検索 (対象: 全ログ)(_A)") );
     action_group()->add( Gtk::Action::create( "ExecSearchCacheAll", "検索する(_E)"), sigc::mem_fun( *this, &ArticleViewBase::slot_search_cacheall ) );
     action_group()->add( Gtk::Action::create( "SearchTitle", CONFIG::get_menu_search_title() + "(_T)" ), sigc::mem_fun( *this, &ArticleViewBase::slot_search_title ) );
 
@@ -233,7 +233,7 @@ void ArticleViewBase::setup_action()
     action_group()->add( Gtk::Action::create( "DrawoutRes", "レス抽出(_R)"), sigc::mem_fun( *this, &ArticleViewBase::slot_drawout_res ) );
     action_group()->add( Gtk::Action::create( "DrawoutNAME", "名前抽出(_E)"), sigc::mem_fun( *this, &ArticleViewBase::slot_drawout_name ) );
     action_group()->add( Gtk::Action::create( "DrawoutID", "ID抽出(_I)"), sigc::mem_fun( *this, &ArticleViewBase::slot_drawout_id ) );
-    action_group()->add( Gtk::Action::create( "DrawoutBM", "ブックマーク抽出(_B)"), sigc::mem_fun( *this, &ArticleViewBase::slot_drawout_bm ) );
+    action_group()->add( Gtk::Action::create( "DrawoutBM", "しおり抽出(_B)"), sigc::mem_fun( *this, &ArticleViewBase::slot_drawout_bm ) );
     action_group()->add( Gtk::Action::create( "DrawoutURL", "URL抽出(_U)"), sigc::mem_fun( *this, &ArticleViewBase::slot_drawout_url ) );
     action_group()->add( Gtk::Action::create( "DrawoutRefer", "参照抽出(_E)"), sigc::mem_fun( *this, &ArticleViewBase::slot_drawout_refer ) );
     action_group()->add( Gtk::Action::create( "DrawoutAround", "周辺抽出(_A)"), sigc::mem_fun( *this, &ArticleViewBase::slot_drawout_around ) );
@@ -414,16 +414,15 @@ void ArticleViewBase::setup_action()
     "<menu action='Search_Menu'>"
 
     "<menuitem action='SearchWeb'/>"
-    "<menuitem action='SearchTitle' />"
-
     "<separator/>"
 
-    "<menu action='SearchCache_Menu'>"
+    "<menuitem action='SearchTitle' />"
+    "<separator/>"
+
     "<menuitem action='SearchCacheLocal'/>"
     "<menu action='SearchCacheAll'>"
     "<menuitem action='ExecSearchCacheAll'/>"
     "</menu>"
-    "</menu>"
 
     "</menu>"
 
@@ -912,6 +911,13 @@ void ArticleViewBase::goto_bottom()
 void ArticleViewBase::goto_num( int num )
 {
     assert( m_drawarea );
+
+    if( m_drawarea->get_seen_current() == num ) return;
+
+#ifdef _DEBUG
+    std::cout << "ArticleViewBase::goto_num num = " << num << std::endl;
+#endif
+
     m_drawarea->set_jump_history();
     m_drawarea->goto_num( num );
 }
@@ -1331,7 +1337,7 @@ void ArticleViewBase::show_bm()
     std::list< int > list_resnum = m_article->get_res_bm();
 
     if( ! list_resnum.empty() ) append_res( list_resnum );
-    else append_html( "ブックマークはセットされていません" );
+    else append_html( "しおりはセットされていません" );
 }
 
 
@@ -2209,6 +2215,7 @@ void ArticleViewBase::hide_popup( bool force )
     }
 
     m_popup_win->hide();
+    if( m_popup_win->view() ) m_popup_win->view()->stop();
     m_popup_shown = false;
 }
 
