@@ -8,7 +8,11 @@
 #include "jdiconv.h"
 #include "jdregex.h"
 
+#include "dbtree/spchar_decoder.h"
+
 #include <sstream>
+#include <cstring>
+#include <cstdlib>
 
 
 //
@@ -241,7 +245,7 @@ std::list< std::string > MISC::remove_commentline_from_list( std::list< std::str
 
 
 //
-// 空白とカンマで区切られた str_in の文字列をリストにして出力
+// 空白と""で区切られた str_in の文字列をリストにして出力
 //
 // \"は " に置換される
 //
@@ -264,7 +268,7 @@ std::list< std::string > MISC::strtolist( std::string& str_in )
 
 
 //
-// list_in の文字列リストを空白とカンマで区切ってストリングにして出力
+// list_in の文字列リストを空白と""で区切ってストリングにして出力
 //
 // "は \" に置換される
 //
@@ -331,18 +335,65 @@ std::string MISC::remove_space( const std::string& str )
 }
 
 
+//
+// str前後の改行、タブ、スペースを削除
+//
+std::string MISC::remove_spaces( const std::string& str )
+{
+    if( str.empty() ) return std::string();
+
+    size_t l = 0, r = str.length();
+
+    while( l < r
+         && ( str[l] == '\n'
+           || str[l] == '\r'
+           || str[l] == '\t'
+           || str[l] == ' ' ) ) ++l;
+
+    // 最後の文字の位置は文字数より1少ない
+    size_t p = r - 1;
+    while( p > 0
+         && ( str[p] == '\n'
+           || str[p] == '\r'
+           || str[p] == '\t'
+           || str[p] == ' ' ) ){ --p; --r; }
+
+    return str.substr( l, r - l );
+}
+
+
+
 //
 // str1からstr2で示された文字列を除く
 //
 std::string MISC::remove_str( const std::string& str1, const std::string& str2 )
 {
-    std::string str_out;
-    std::string::size_type pos = str1.find( str2 );
-    if( pos != std::string::npos ) str_out = str1.substr( 0, pos ) + str1.substr( pos + str2.length() );
+    return MISC::replace_str( str1, str2, "" );
+}
+
+
+//
+// start 〜 end の範囲をstrから取り除く ( /* コメント */ など )
+//
+std::string MISC::remove_str( const std::string& str, const std::string& start, const std::string& end )
+{
+    std::string str_out = str;
+
+    size_t l_pos = 0, r_pos = 0;
+    const size_t start_length = start.length();
+    const size_t end_length = end.length();
+
+    while( ( l_pos = str_out.find( start, l_pos ) ) != std::string::npos &&
+            ( r_pos = str_out.find( end, l_pos + start_length ) ) != std::string::npos )
+    {
+        str_out.erase( l_pos, r_pos - l_pos + end_length );
+    }
+
     return str_out;
 }
 
 
+
 //
 // 正規表現を使ってstr1からqueryで示された文字列を除く
 //
@@ -531,8 +582,9 @@ std::string MISC::cut_str( const std::string& str, unsigned int maxsize )
     std::string outstr = str;
     unsigned int pos, lng_str;
     int byte = 0;
+    const size_t outstr_length = outstr.length();
 
-    for( pos = 0, lng_str = 0; pos < outstr.length(); pos += byte ){
+    for( pos = 0, lng_str = 0; pos < outstr_length; pos += byte ){
         MISC::utf8toucs2( outstr.c_str()+pos, byte );
         if( byte > 1 ) lng_str += 2;
         else ++lng_str;
@@ -540,13 +592,221 @@ std::string MISC::cut_str( const std::string& str, unsigned int maxsize )
     }
 
     // カットしたら"..."をつける
-    if( pos != outstr.length() ) outstr = outstr.substr( 0, pos ) + "...";
+    if( pos != outstr_length ) outstr = outstr.substr( 0, pos ) + "...";
 
     return outstr;
 }
 
 
 
+//
+// HTMLエスケープ
+//
+// include_url : URL中でもエスケープする( デフォルト = true )
+//
+std::string MISC::html_escape( const std::string& str, const bool include_url )
+{
+    if( str.empty() ) return str;
+
+    bool is_url = false;
+    int scheme = SCHEME_NONE;
+    std::string str_out;
+    const size_t str_length = str.length();
+
+    for( size_t pos = 0; pos < str_length; ++pos )
+    {
+        char tmpchar = str.c_str()[ pos ];
+
+        // URL中はエスケープしない場合
+        if( ! include_url )
+        {
+            // URLとして扱うかどうか
+            // エスケープには影響がないので loose_url としておく
+            if( scheme != SCHEME_NONE ) is_url = is_url_char( str.c_str() + pos, true );
+
+            // URLスキームが含まれているか判別
+            int len = 0;
+            if( ! is_url ) scheme = is_url_scheme( str.c_str() + pos, len );
+
+            // URLスキームが含まれていた場合は文字数分進めてループに戻る
+            if( len > 0 )
+            {
+                str_out += str.substr( pos, len );
+                pos += len - 1; // あとで ++pos される分を引く
+                continue;
+            }
+        }
+
+        // include_url = false でURL中ならエスケープしない
+        if( is_url ) str_out += tmpchar;
+        else if( tmpchar == '&' )
+        {
+            const int bufsize = 64;
+            char out_char[ bufsize ];
+            int n_in, n_out;
+            DBTREE::decode_char( str.c_str() + pos, n_in, out_char, n_out );
+
+            if( n_out ) str_out += tmpchar;
+            else str_out += "&amp;";
+        }
+        else if( tmpchar == '\"' ) str_out += "&quot;";
+        else if( tmpchar == '<' ) str_out += "&lt;";
+        else if( tmpchar == '>' ) str_out += "&gt;";
+        else str_out += tmpchar;
+    }
+
+#ifdef _DEBUG
+    if( str != str_out ){
+        std::cout << "MISC::html_escape\nstr = " << str << std::endl
+                  << "out = " << str_out << std::endl;
+    }
+#endif
+
+    return str_out;
+}
+
+
+//
+// HTMLアンエスケープ
+//
+std::string MISC::html_unescape( const std::string& str )
+{
+    if( str.empty() ) return str;
+    if( str.find( "&" ) == std::string::npos ) return str;
+
+    std::string str_out;
+    const size_t str_length = str.length();
+
+    for( size_t pos = 0; pos < str_length; ++pos ){
+
+        const int bufsize = 64;
+        char out_char[ bufsize ];
+        int n_in, n_out;
+        DBTREE::decode_char( str.c_str() + pos, n_in, out_char, n_out );
+
+        if( n_out ){
+            str_out += out_char;
+            pos += n_in -1;
+        }
+        else str_out += str.c_str()[ pos ];
+    }
+
+#ifdef _DEBUG
+    if( str != str_out ){
+        std::cout << "MISC::html_unescape\nstr = " << str << std::endl
+                  << "out = " << str_out << std::endl;
+    }
+#endif
+
+    return str_out;
+}
+
+
+
+//
+// URL中のスキームを判別する
+//
+// 戻り値 : スキームタイプ
+// len    : "http://"等の文字数
+//
+int MISC::is_url_scheme( const char* str_in, int& len )
+{
+    int scheme = SCHEME_NONE;
+    len = 0;
+
+    // 候補になり得ない場合は以降の処理はしない
+    if( *str_in != 'h' && *str_in != 'f' && *str_in != 't' ) return scheme;
+
+    // http https
+    if( *str_in == 'h' && *( str_in + 1 ) == 't'
+        && *( str_in + 2 ) == 't' && *( str_in + 3 ) == 'p' )
+    {
+        scheme = SCHEME_HTTP;
+        len = 4;
+        if( *( str_in + len ) == 's' ) ++len;
+    }
+    // ftp
+    else if( *str_in == 'f' && *( str_in + 1 ) == 't' && *( str_in + 2 ) == 'p' )
+    {
+        scheme = SCHEME_FTP;
+        len = 3;
+    }
+    // ttp ttps
+    else if( *str_in == 't' && *( str_in + 1 ) == 't' && *( str_in + 2 ) == 'p' )
+    {
+        scheme = SCHEME_TTP;
+        len = 3;
+        if( *( str_in + len ) == 's' ) ++len;
+    }
+    // tp tps
+    else if( *str_in == 't' && *( str_in + 1 ) == 'p' )
+    {
+        scheme = SCHEME_TP;
+        len = 2;
+        if( *( str_in + len ) == 's' ) ++len;
+    }
+
+    // 各スキーム後に続く共通の"://"
+    if( *( str_in + len ) == ':' && *( str_in + len + 1 ) == '/'
+        && *( str_in + len + 2 ) == '/' ) len += 3;
+    else scheme = SCHEME_NONE;
+
+    return scheme;
+}
+
+
+//
+// URLとして扱う文字かどうか判別する
+//
+// 基本 : 「!#$%&'()*+,-./0-9:;=?@A-Z_a-z~」
+// 拡張 : 「[]^|」
+//
+// "RFC 3986" : http://www.ietf.org/rfc/rfc3986.txt
+// "RFC 2396" : http://www.ietf.org/rfc/rfc2396.txt
+//
+bool MISC::is_url_char( const char* str_in, const bool loose_url )
+{
+    if(
+        // 出現頻度が高いと思われる順にチェック
+        ( *str_in >= 'a' && *str_in <= 'z' )
+        || ( *str_in >= '0' && *str_in <= '9' )
+        || ( *str_in >= 'A' && *str_in <= 'Z' )
+        || *str_in == '.'
+        || *str_in == '/'
+        || *str_in == '-'
+        || *str_in == '%'
+        || *str_in == '?'
+        || *str_in == '='
+        || *str_in == ':'
+        || *str_in == '~'
+        || *str_in == '&'
+
+        // あとの並びはASCIIコード順(なんとなく)
+        || *str_in == '!'
+        || *str_in == '#'
+        || *str_in == '$'
+        || *str_in == '\''
+        || *str_in == '('
+        || *str_in == ')'
+        || *str_in == '*'
+        || *str_in == '+'
+        || *str_in == ','
+        || *str_in == ';'
+        || *str_in == '@'
+        || *str_in == '_'
+
+        // RFC 3986(2.2.)では"[]"が予約文字として定義されているが
+        // RFC 2396(2.4.3.)では除外されていて、普通にURLとして扱う
+        // と問題がありそうなので"loose_url"の扱いにしておく。
+        || ( loose_url && ( *str_in == '['
+                         || *str_in == ']'
+                         || *str_in == '^'
+                         || *str_in == '|' ) )
+    ) return true;
+    else return false;
+}
+
+
 //
 // url エンコード
 //
@@ -596,7 +856,7 @@ std::string MISC::url_encode( const char* str, size_t n )
 //
 std::string MISC::charset_url_encode( const std::string& str, const std::string& charset )
 {
-    if( charset.empty() ) return MISC::url_encode( str.c_str(), str.length() );
+    if( charset.empty() || charset == "UTF-8" ) return MISC::url_encode( str.c_str(), str.length() );
 
     std::string str_enc = MISC::Iconv( str, "UTF-8", charset );
     std::string str_encoded = MISC::url_encode( str_enc.c_str(), strlen( str_enc.c_str() ) );
@@ -605,6 +865,26 @@ std::string MISC::charset_url_encode( const std::string& str, const std::string&
 }
 
 
+//
+// 文字コード変換して url エンコード
+//
+// ただし半角スペースのところを+に置き換えて区切る
+//
+std::string MISC::charset_url_encode_split( const std::string& str, const std::string& charset )
+{
+    std::list< std::string > list_str = MISC::split_line( str );
+    std::list< std::string >::iterator it = list_str.begin();
+    std::string str_out;
+    for( ; it != list_str.end(); ++it ){
+
+        if( it != list_str.begin() ) str_out += "+";
+        str_out += MISC::charset_url_encode( *it, charset );
+    }
+
+    return str_out;
+}
+
+
 //
 // BASE64
 //
@@ -768,7 +1048,9 @@ int MISC::ucs2toutf8( int ucs2, char* utfstr )
 std::string MISC::toupper_str( const std::string& str )
 {
     std::string str_out;
-    for( size_t i = 0; i < str.length() ; ++i ) str_out += toupper( str[ i ] );
+    const size_t str_length = str.length();
+
+    for( size_t i = 0; i < str_length ; ++i ) str_out += toupper( str[ i ] );
 
     return str_out;
 }
@@ -794,8 +1076,9 @@ std::list< std::string > MISC::toupper_list( std::list< std::string >& list_str
 std::string MISC::tolower_str( const std::string& str )
 {
     std::string str_out;
+    const size_t str_length = str.length();
 
-    for( size_t i = 0; i < str.length() ; ++i ) str_out += tolower( str[ i ] );
+    for( size_t i = 0; i < str_length; ++i ) str_out += tolower( str[ i ] );
 
     return str_out;
 }
@@ -854,3 +1137,35 @@ std::string MISC::get_dir( const std::string& path )
 
     return path.substr( 0, i+1 );
 }
+
+
+
+//
+// SVNリビジョンとして表示する文字列を返す
+//
+std::string MISC::get_svn_revision( const char* rev )
+{
+    std::string svn_revision = "svn." + std::string( __DATE__ ) + "-" + std::string( __TIME__ );
+
+    if( ! rev ) return svn_revision;
+
+    // "2000:2002MS"など[0-9:MS]の形式かどうか
+    bool valid = true;
+    unsigned int n;
+    const size_t rev_length = strlen( rev );
+    for( n = 0; n < rev_length; ++n )
+    {
+        if( (unsigned char)( rev[n] - 0x30 ) > 0x0A
+            && rev[n] != 'M'
+            && rev[n] != 'S' )
+        {
+            valid = false;
+            break;
+        }
+    }
+
+    if( valid ) svn_revision = std::string( "SVN Rev." ) + std::string( rev );
+
+    return svn_revision;
+}
+
