@@ -16,7 +16,12 @@
 #include "jdlib/loaderdata.h"
 #include "jdlib/miscmsg.h"
 
-#define SIZE_OF_RAWDATA ( 64 * 1024 )
+#include <cstring>
+
+enum
+{
+    SIZE_OF_RAWDATA = 64 * 1024
+};
 
 LOGIN::Login2ch* instance_login2ch = NULL;
 
@@ -195,7 +200,7 @@ void Login2ch::receive_finish()
         mdiag.run();
     }
     else if( get_username().empty() || get_passwd().empty() ){
-        SKELETON::MsgDiag mdiag( NULL, "IDまたはパスワードが設定されていません\n\n設定→ネットワーク→2chログインで設定してください" );
+        SKELETON::MsgDiag mdiag( NULL, "IDまたはパスワードが設定されていません\n\n設定→ネットワーク→パスワードで設定してください" );
         mdiag.run();
     }
     else if( show_err ){
