@@ -1,6 +1,7 @@
 // ライセンス: GPL2
 
 //#define _DEBUG
+//#define _DEBUG_MEM_PROFILE
 #include "jddebug.h"
 
 #include "config/globalconf.h"
@@ -16,6 +17,7 @@
 #include <string>
 #include <sys/time.h>
 #include <errno.h>
+#include <cstring>
 
 #ifdef USE_GNOMEUI
 #include <gnome.h>
@@ -113,7 +115,7 @@ void restore_bkup()
     if( bkup_main || bkup_favor ){
 
         Gtk::MessageDialog* mdiag
-        = new Gtk::MessageDialog( "前回の起動時に正しくJDが終了されませんでした。\n\n板リストとお気に入りをバックアップファイルから復元しますか？\nキャンセルを押すとバックアップファイルを削除します。",
+        = new Gtk::MessageDialog( "前回の起動時に正しくJDが終了されませんでした。\n\n板リストとお気に入りをバックアップファイルから復元しますか？\nいいえを押すとバックアップファイルを削除します。",
                                   false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
         int ret = mdiag->run();
         delete mdiag;
@@ -359,6 +361,10 @@ int main( int argc, char **argv )
         exit( 1 );
     }
 
+#ifdef _DEBUG_MEM_PROFILE
+    g_mem_set_vtable( glib_mem_profiler_table );
+    atexit( g_mem_profile );
+#else
     GMemVTable vtable;
     vtable = *glib_mem_profiler_table;
     vtable.malloc = malloc;
@@ -368,6 +374,7 @@ int main( int argc, char **argv )
     vtable.try_malloc = malloc;
     vtable.try_realloc = realloc;
     g_mem_set_vtable( &vtable );
+#endif
 
     Gtk::Main m( &argc, &argv );
 
