@@ -35,6 +35,7 @@
 
 #include <sstream>
 #include <sys/time.h>
+#include <cstring>
 
 
 using namespace MESSAGE;
@@ -299,7 +300,7 @@ void MessageViewBase::save_name()
 void MessageViewBase::pack_widget()
 {
     // ツールバー
-    set_toolbar( Gtk::manage( new MessageToolBar( " [ " + DBTREE::board_name( get_url() ) + " ]  " ) ) );
+    set_toolbar( Gtk::manage( new MessageToolBar( DBTREE::board_name( get_url() ) ) ) );
     get_messagetoolbar()->m_entry_subject.set_text( DBTREE::article_subject( get_url() ) );
     get_messagetoolbar()->m_button_not_close.set_active( ! SESSION::get_close_mes() );
 
